@@ -1,6 +1,6 @@
 gMCP <- function(graph, pvalues, test, correlation, alpha=0.05, 
 		approxEps=TRUE, eps=10^(-3), ..., useC=FALSE, 
-		verbose=FALSE, keepWeights=TRUE, adjPValues=TRUE) {	
+		verbose=FALSE, keepWeights=TRUE, adjPValues=TRUE, exhaustAlpha=FALSE) {	
 	output <- ""
 	if (approxEps && !is.numeric(graph@m)) {
 		graph <- substituteEps(graph, eps=eps)
@@ -41,6 +41,7 @@ gMCP <- function(graph, pvalues, test, correlation, alpha=0.05,
 		}
 	} else if (missing(test) && !missing(correlation)) {
 		# Calling the code from Florian
+		checkOptimal(graph)
 		if (missing(correlation) || (!is.matrix(correlation) && !is.character(correlation))) {
 			stop("Procedure for correlated tests, expects a correlation matrix as parameter \"correlation\".")
 		} else {
@@ -62,7 +63,7 @@ gMCP <- function(graph, pvalues, test, correlation, alpha=0.05,
 				#myTest <- generateTest(Gm, w, correlation, alpha)
 				#zScores <- -qnorm(pvalues)
 				#rejected <- myTest(zScores)
-                adjP <- generatePvals(Gm,w,correlation,pvalues)
+                adjP <- generatePvals(Gm, w, correlation, pvalues, exhaust=exhaustAlpha)
                 rejected <- adjP <= alpha
                 names(adjP) <- getNodes(graph)
 				names(rejected) <- getNodes(graph)
