@@ -1,4 +1,4 @@
-graphTest <- function(pvalues, weights = NULL, alpha = 0.05, G = NULL, graph = NULL, verbose = FALSE) {
+graphTest <- function(pvalues, weights = NULL, alpha = 0.05, G = NULL, cr = NULL, graph = NULL, verbose = FALSE) {
 	
 	usegraph <- !is.null(graph)
 	if(usegraph & (class(graph) != "graphMCP"))
@@ -17,33 +17,45 @@ graphTest <- function(pvalues, weights = NULL, alpha = 0.05, G = NULL, graph = N
 	nH <- as.integer(nH)
 	checkArgs(pvalues, alphas, G, nH)
 	
-	if(is.list(G)){
-		nGraphs <- length(G)
-		G <- c(unlist(G))
-	} else {
-		nGraphs <- as.integer(1)
-	}
-	if(!is.matrix(pvalues)){
-		res <- .C("graphproc", h=double(nH), a=as.double(alphas), G=as.double(G),
-				as.double(pvalues), nH, as.double(G), as.integer(nGraphs),
-				as.integer(verbose))
-		out <- c(H = res$h)
-		attr(out, "last.alphas") <- res$a
-		attr(out, "last.G") <- matrix(res$G, ncol = nH)
-		return(out)
-	} else {
-		nCount <- as.integer(nrow(pvalues))
-		res <- .C("graphmult", h=double(nH*nCount), double(nH),
-				as.double(alphas), double(nGraphs*nH),
-				as.double(G), as.double(G), as.double(G),
-				as.double(pvalues), double(nH), nCount, nH,
-				as.integer(nGraphs), as.integer(verbose))
-		out <- matrix(res$h, nrow = nCount)
-		if(is.null(colnames(G)))
-			colnames(out) <- paste("H", 1:nH, sep="")
-		else
-			colnames(out) <- colnames(G)
+	if (!is.null(cr)) { # parametric case
+		hint <- generateWeights(G, weights)
+		out <- matrix(0, nrow=0, ncol=dim(pvalues)[2])
+		colnames(out) <- colnames(G)
+		for (i in 1:(dim(pvalues)[1])) {
+			adjP <- generatePvals(G, weights, cr, pvalues[i,], hint=hint)
+			out <- rbind(out, ifelse(adjP<=alpha,1,0))
+		}
 		return(out)
+	} else { # non-parametric case		
+		if(is.list(G)){
+			nGraphs <- length(G)
+			G <- c(unlist(G))
+		} else {
+			nGraphs <- as.integer(1)
+		}
+		if(!is.matrix(pvalues)){
+			res <- .C("graphproc", h=double(nH), a=as.double(alphas), G=as.double(G),
+					as.double(pvalues), nH, as.double(G), as.integer(nGraphs),
+					as.integer(verbose))
+			out <- c(H = res$h)
+			attr(out, "last.alphas") <- res$a
+			attr(out, "last.G") <- matrix(res$G, ncol = nH)
+			return(out)
+		} else {
+			nCount <- as.integer(nrow(pvalues))
+			res <- .C("graphmult", h=double(nH*nCount), double(nH),
+					as.double(alphas), double(nGraphs*nH),
+					as.double(G), as.double(G), as.double(G),
+					as.double(pvalues), double(nH), nCount, nH,
+					as.integer(nGraphs), as.integer(verbose))
+			out <- matrix(res$h, nrow = nCount)
+			if(is.null(colnames(G))) {
+				colnames(out) <- paste("H", 1:nH, sep="")
+			} else {
+				colnames(out) <- colnames(G)
+			}
+			return(out)
+		}
 	}
 }
 
