@@ -15,7 +15,9 @@ public class EpsilonTableCellRenderer extends DefaultTableCellRenderer {
 	
 	private static final Log logger = LogFactory.getLog(EpsilonTableCellRenderer.class);
 	
-	public EpsilonTableCellRenderer() { super(); }
+	public EpsilonTableCellRenderer() { 
+		super(); 
+	}
 
     public void setValue(Object value) {
     	setText(value.toString());
@@ -23,24 +25,23 @@ public class EpsilonTableCellRenderer extends DefaultTableCellRenderer {
 
     public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int col)	{    	
     	DataTableModel model = (DataTableModel) table.getModel();
-
+    	
     	double sum = 0;
-
-    	for (int i=0; i<model.getColumnCount(); i++) {
-    		EdgeWeight ew = model.getValueAt(row, i);
-    		Double d = 0.0;
-    		try {
-    			d = ew.getWeight(null);
-    		} catch (Exception e) {
-    			// Seriously - we don't want to do anything: d=0.0 is fine.
+    	if (model.checkRowSum()) {    		
+    		for (int i=0; i<model.getColumnCount(); i++) {
+    			EdgeWeight ew = model.getValueAt(row, i);
+    			Double d = 0.0;
+    			try {
+    				d = ew.getWeight(null);
+    			} catch (Exception e) {
+    				// Seriously - we don't want to do anything: d=0.0 is fine.
+    			}
+    			if (d>1.0001||d<0) sum=1000;
+    			sum += (d>=0&&d<=1)?d:0;
     		}
-    		if (d>1.0001||d<0) sum=1000;
-    		sum += (d>=0&&d<=1)?d:0;
     	}
 
-    	DefaultTableCellRenderer dtcr = new DefaultTableCellRenderer();
-        JLabel label = (JLabel) dtcr.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, col);       
-   
+        JLabel label = (JLabel) super.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, col);       
         
         String text = value.toString();
         
@@ -58,7 +59,7 @@ public class EpsilonTableCellRenderer extends DefaultTableCellRenderer {
     		label.setBackground(null);
     	}
     	
-    	if ((row==col && !((DataTableModel)table.getModel()).diagEditable) || model.testing) {
+    	if ((row==col && ! model.diagEditable) || model.testing) {
     		label.setForeground(Color.LIGHT_GRAY);
     	}
     	
